selm modelsselm models
when method="MPLE". Qpenalty is the default function;
MPpenalty is an example of a user-defined function effectively
corresponding to a prior distributio on alpha.Qpenalty(alpha_etc, nu = NULL, der = 0)MPpenalty(alpha, der = 0)
alpha;
in the multivariate case, a two-component list whose first component is
the vector alpha, the second one is matrix cov2cor(Omega).selm is called
with family="ST".der equal to 0 or 1.Q representing the penalty, possibly
with attributes attr(Q, "der1") and attr(Q, "der2"),
depending onthe input value der.alpha, but its expression may
depend on other ingredients, specifically nu and cov2cor(Omega).
See selm for additional information.The penalty mechanism allows to introduce a prior distribution $\pi$ for $\alpha$ by setting $Q=-\log\pi$, leading to a maximum a posteriori estimate in the stated sense.
As an illustration of this mechanism, function MPpenalty implements the
`matching prior' distribution for the univariate SN distribution
studied by Cabras et al. (2012); a brief summary of the proposal is
provided in Section 3.2 of Azzalini and Capitanio (2014).
Note that, besides alpha=+/-Inf, this choice also penalizes
alpha=0 with Q=Inf, effectively removing alpha=0
from the parameter space.
selm functiondata(frontier)
m2 <- selm(frontier ~ 1)
m2a <- selm(frontier ~ 1, method="MPLE")
m2b <- selm(frontier ~ 1, method="MPLE", penalty="MPpenalty")Run the code above in your browser using DataLab