Learn R Programming

sn (version 1.0-0)

SECdistrMv-class: Class "SECdistrMv"

Description

Multivariate skew-elliptically contoured distributions

Arguments

Objects from the Class

Objects can be created by a call to function makeSECdistr, when its argument dp is a list, or by a suitable transformation of some object of this class.

See Also

SECdistrUv, plot,SECdistrMv-method, summary,SECdistrMv-method, affineTransSECdistr, marginalSECdistr

Examples

Run this code
dp0 <- list(xi=1:2, Omega=diag(3:4), alpha=c(3, -5))
  f10 <- makeSECdistr(dp=dp0, family="SN", name="SN-2D", compNames=c("x", "y"))
  show(f10)
  plot(f10)
  summary(f10)

Run the code above in your browser using DataLab