Learn R Programming

sn (version 1.2-2)

SECdistrUv-class: Class "SECdistrUv"

Description

Univariate skew-elliptically contoured distributions

Arguments

Objects from the class

Objects can be created by a call to function makeSECdistr when its argument dp is a vector. They can also obtained from an object generated by selm using the function extractSEDdistr.

See Also

SECdistrMv, plot,SECdistrUv-method, summary,SECdistrUv-method, extractSECdistr

Examples

Run this code
f2 <- makeSECdistr(dp=c(3, 5, -pi, 6), family="ST", name="My first ST")
show(f2)
plot(f2)
plot(f2, probs=c(1,5,9)/10)
plot(f2, range=c(-30,10), probs=NULL, col=2, main=NULL)
summary(f2)
mean(f2)  # the mean value of the probability distribution
sd(f2)  # the standard deviation of the distribution

Run the code above in your browser using DataLab