Description
Evaluates function $T(h,a)$ studied by D.B.OwenUsage
T.Owen(h, a, jmax=50, cut.point=8)
Arguments
h
a numerical vector. Missing values (NAs) and Inf are allowed.
a
a numerical scalar. Inf is allowed.
jmax
an integer scalar value which regulates the accuracy of the result.
See the section Details below for explanation.
cut.point
a scalar value which regulates the behaviour of the algorithm, as
explained by the details below (default value: 8).
Background
The function T(h,a) studied by Owen (1956) is useful for the computation
of the bivariate normal distribution function and related quantities,
including the distribution function of a skew-normal variate; see psn.
See the reference below for more information on function $T(h,a)$.Details
If a>1 and 0, a series expansion is used,
truncated after jmax terms.
If a>1 and h>cut.point, an asymptotic approximation is used.
In the other cases, various reflection properties of the function
are exploited. See the reference below for more information.References
Owen, D. B. (1956).
Tables for computing bivariate normal probabilities.
Ann. Math. Statist.
27, 1075-1090.