Learn R Programming

sn (version 2.1.3)

affineTransSECdistr: Affine transformations and marginals of a skew-elliptical distribution

Description

Given a multivariate random variable \(Y\) with skew-elliptical (SEC) distribution, compute the distribution of a (possibly multivariate) marginal or the distribution of an affine transformation \(a + A^{\top}Y\).

Usage

affineTransSECdistr(object, a, A, name, compNames, drop=TRUE)
  marginalSECdistr(object, comp, name, drop=TRUE)

Arguments

Value

If object defines the distribution of a SEC random variable \(Y\), affineTransSECdistr computes the distribution of \(a+A'Y\) and marginalSECdistr computes the marginal distribution of the comp components. In both cases the returned object is of class SECdistrMv, except when drop=TRUE

operates, leading to an object of class SECdistrUv.

References

Azzalini, A. with the collaboration of Capitanio, A. (2014). The Skew-Normal and Related Families. Cambridge University Press, IMS Monographs series.

See Also

makeSECdistr, extractSECdistr, SECdistrMv-class

Examples

Run this code
dp3 <- list(xi=1:3, Omega=toeplitz(1/(1:3)), alpha=c(3,-1,2), nu=5)
st3 <- makeSECdistr(dp3, family="ST", name="ST3", compNames=c("U", "V", "W"))
A <- matrix(c(1,-1,1, 3,0,-2), 3, 2)
new.st <- affineTransSECdistr(st3, a=c(-3,0), A=A)
#
st2 <- marginalSECdistr(st3, comp=c(3,1), name="2D marginal of ST3")

Run the code above in your browser using DataLab