selm fit and corresponding confidence interval or regions## S3 method for class 'selm':
profile(fitted, param.type, param.name, param.values, npt,
opt.control = list(), plot.it = TRUE, log = TRUE, level,
trace = FALSE, ...)selm as produced by a call to
function selm with univariate response."CP" or "DP", or possibly their equivalent lowercase.summaryparam.values
has length 2, an equally spaced grid of values is build with length equal
to the corresponding component of npt.
If the above condition is met but this acontrol to optim to
optimize the log-likelihood; see TRUE (default value), a plot
is produced representing the deviance, which is described in
level
is mTRUE) indicating whether the
scale and tail-weight parameters must be log-transformed, if case any of
them occurs in param.name. This applied to omega and
nu in the <FALSE) to activate printing
of intermediate outcome of the log-likelihood optimization processoptim
optimization function, with method="BFGS". This step can be regulated by
the user via opt.control which is passed to optim
as control argument, apart from element fnscale whose use is
reserved.If the original fitted object included a fixed parameter value,
this is kept fixed here. If the estimation method was "MPLE",
that choice carries on here; in case the penalty function was user-defined,
it must still be accessible.
For plotting purposes and also in the numerical output, the deviance function $D$ is used, namely $$D = 2\left[\max(\log L) - \log L\right]$$ where $L$ denotes the likelihood.
The range of param.values must enclose the maximum (penalized)
likelihood estimates (MLE or MPLE) by an adequate extent
such that suitable confidence intervals or regions can be established from
standard asymptotic theory.
For the SN family and DP parameterization, the asymptotic
theory is actually non-standard near the important point $\alpha=0$,
but the correspondence with the regular case of the CP
parameterization, still allows to derive confidence regions using standard
procedures; for more information on this point, see Section 3.1.6 of
Azzalini and Capitanio (2014).
When the MLE occurs on the frontier of the parameter space,
a message is issued and no confidence interval is produced, while in the
two-parameter case the plot is not labelled with probability values, but only
deviance levels.
selm, summary.selm,makeSECdistr for the CP/DP parameterizations,
optim for its control argument
data(ais)
m1 <- selm(log(Fe) ~ BMI + LBM, family = "sn", data = ais)
pll <- profile(m1, "dp", param.name="alpha", param.val=c(-3,2))
profile(m1, "cp", param.name="gamma1", param.val=seq(-0.7, 0.5, by=0.1))
# reduce grid points to save time
pll <- profile(m1, "cp", param.name=c("(Intercept.CP)", "gamma1"),
param.val=list(c(1.5, 4), c(-0.8, 0.5)), npt=c(11,16) )Run the code above in your browser using DataLab