Learn R Programming

sn (version 1.2-2)

residuals.selm: Residuals and fitted values from selm fits

Description

residuals and fitted methods for classes "selm" and "mselm".

Usage

## S3 method for class 'selm':
residuals(object, param.type = "CP", ...)
## S3 method for class 'mselm':
residuals(object, param.type = "CP", ...)
## S3 method for class 'selm':
fitted(object, param.type = "CP", ...)
## S3 method for class 'mselm':
fitted(object, param.type = "CP", ...)

Arguments

object
an object of class "selm" or "mselm" as created by a call to function selm.
param.type
a character string which indicates the required type of parameter type; possible values are "CP" (default), "DP", "pseudo-CP" and their equivalent lower-case expressions.
...
not used, included for compatibility with the generic method

Value

  • a numeric vector (for selm-class objects) or a matrix (for mselm-class objects)

References

Azzalini, A. with the collaboration of Capitanio, A. (2014). The Skew-Normal and Related Families. Cambridge University Press, IMS Monographs series.

See Also

dp2cp, summary.selm, selm function, selm-class

Examples

Run this code
data(wines, package="sn")
m5 <- selm(acidity ~ phenols + wine, family="SN", data=wines)
residuals(m5)
residuals(m5, "dp")
fitted(m5, "dp")
#
m12 <- selm(cbind(acidity, alcohol) ~ phenols + wine,  family="SN", data=wines)
residuals(m12)
#
# see other examples at function selm

Run the code above in your browser using DataLab