sn.infoUv(dp=NULL, cp=NULL, x=NULL, y, w, penalty=NULL, norm2.tol=1e-06)
sn.infoMv(dp, x=NULL, y, w, norm2.tol=1e-06)st.infoUv(dp=NULL, cp=NULL, x=NULL, y, fixed.nu=NULL, w, penalty=NULL,
norm2.tol=1e-06)
st.infoMv(dp, x=NULL, y, fixed.nu=NULL, w, penalty=NULL, norm2.tol=1e-06)
sn.infoUv is to be used, and these arguments are
vectors. In the multivariate casesn.infoUv and st.infoUv)
or a matrix (for sn.infoMv and st.infoMv) representing the
response. In the SN case ( sn.infoUv and
sn.infoMnu. If not NULL, the information matrix
has a dimension reduced by 1.selm; see this function for its description;norm2.tol, a
warning message is issued, since the x is not set, then a simple random sample
is assumed and a matrix x with a single column of all 1's is
constructed; in this case, the supplied vector dp or cp must
have length 3. If x is set, then the supplied vector of parameters,
dp or cp, must have length ncol(x)+2.
In the multivariate case, a direct extension of this scheme applies.If the observed information matrix is required, dp or dp should
represent the maximum likelihood estimates (MLE) for the given y,
otherwise the information matrix may fail to be positive-definite. Therefore,
the squared Mahalobis norm of the score vector is evaluated and compared with
norm2.tol. If it exceeds this threshold, it is taken as an indication
that the parameter is not at the MLE and a warning message is issued. The
returned list still includes info.dp and info.cp, but in this
case these represent merely the matrices of second derivatives;
asyvar.dp and asyvar.cp are set to NULL.
Azzalini, A. with the collaboration of Capitanio, A. (2014). The Skew-Normal and Related Families. Cambridge University Press, IMS Monographs series.
dsn, dmsn, dp2cpinfoE <- sn.infoUv(dp=c(0,1,5))
infoO <- sn.infoUv(cp=c(0,1,0.8), y=rsn(50, dp=c(0,1,5)))
#
data(wines)
X <- model.matrix(~ pH + wine, data=wines)
fit <- sn.mple(x=X, y=wines$alcohol)
infoE <- sn.infoUv(cp=fit$cp, x=X)
infoO <- sn.infoUv(cp=fit$cp, x=X, y=wines$alcohol)Run the code above in your browser using DataLab