The penalty is a function of alpha, but its expression may
depend on other ingredients, specifically nu and cov2cor(Omega).
See Details of selm for additional information.The penalty mechanism allows to introduce a prior distribution $\pi$
for $\alpha$ by setting $Q=-\log\pi$,
leading to a maximum a posteriori estimate in the stated sense.
As an illustration of this mechanism, function MPpenalty implements the
`matching prior' distribution for the univariate SN distribution
studied by Cabras et al. (2012); a brief summary of the proposal is
provided in Section 3.2 of Azzalini and Capitanio (2014).
Note that, besides alpha=+/-Inf, this choice also penalizes
alpha=0 with Q=Inf, effectively removing alpha=0
from the parameter space.