Learn R Programming

sn (version 2.1.3)

selm-class: Classes selm and mselm of objects created by function selm

Description

A successful call to function selm creates an object of class either selm or mselm, whose structure is described in section ‘Slots’. A set of methods for object of these classes exist, which are listed in the section ‘Methods’. Specific documentation is provided separately for the methods involving a more extended description; see the section ‘See also’.

Arguments

Objects from the class

An object can be created by a successful call to function selm.

Slots

call:

the calling statement.

family:

the parametric family of skew-ellitically contoured distributed (SEC) type.

logL:

log-likelihood or penalized log-likelihood value achieved at the end of the maximization process.

method:

estimation method ("MLE" or "MPLE").

param:

estimated parameters, for various parameterizations.

param.var:

approximate variance matrices of the parameter estimates, for various parameterizations.

size:

a numeric vector with size of various components.

fixed.param:

a vector of parameters which have been kept fixed in the fitting process, if any.

residuals.dp:

residual values, for DP-type parameters.

fitted.values.dp:

fitted values, for DP-type parameters.

control:

a list with control parameters.

input:

a list of selected input values.

opt.method:

a list with details on the numerical optimization method used in the fitting process.

Methods

coefsignature(object = "selm"): ...
logLiksignature(object = "selm"): ...
plotsignature(x = "selm"): ...
showsignature(object = "selm"): ...
summarysignature(object = "selm"): ...
residualssignature(object = "selm"): ...
fittedsignature(object = "selm"): ...
vcovsignature(object = "selm"): ...
weightssignature(object = "selm"): ...
confintsignature(object = "selm"): ...
predictsignature(object = "selm"): ...
profilesignature(fitted = "selm"): ...
coefsignature(object = "mselm"): ...
logLiksignature(object = "mselm"): ...
plotsignature(x = "mselm"): ...
showsignature(object = "mselm"): ...
summarysignature(object = "mselm"): ...
residualssignature(object = "mselm"): ...
fittedsignature(object = "mselm"): ...
vcovsignature(object = "mselm"): ...
weightssignature(object = "mselm"): ...

Author

Adelchi Azzalini

See Also

See also the selm function, and related methods plot, summary, profile, confint, predict

Examples

Run this code
data(ais)
m1 <- selm(log(Fe) ~ BMI + LBM, family="SN", data=ais)
summary(m1)
plot(m1)
logLik(m1)
res <- residuals(m1)
fv <- fitted(m1)
# 
data(wines, package="sn")
m2 <- selm(alcohol ~ malic + phenols, data=wines)
#
m12 <- selm(cbind(acidity, alcohol) ~ phenols + wine, family="SN", data=wines)
coef(m12)
cp <- coef(m12, vector=FALSE)
dp <- coef(m12, "DP", vector=FALSE)
plot(m12)
plot(m12, which=2, col="gray60", pch=20)

Run the code above in your browser using DataLab